@@ -28,7 +28,7 @@
 import datetime
 import json
 
-import mettle.io
+from mettle.io.py_json_dict_writer import PyJsonDictWriter
 
 from bs_lib import Pod
 
@@ -94,7 +94,7 @@ class BatchArchiveMsgs:
             msg_qry.exec_deft(arch_qry.orec.id).fetch_all(list_msgs)
             msgattr_qry.exec_deft(arch_qry.orec.id, '').fetch_all(list_res)
 
-            writer = mettle.io.PyJsonDictWriter(json_obj)
+            writer = PyJsonDictWriter(json_obj)
 
             arch_qry.orec._serialize(writer)
             list_msgs._serialize(writer)
