@@ -25,13 +25,12 @@
 #  DEALINGS IN THE SOFTWARE.                                                   #
 # **************************************************************************** #
 import datetime
-import json
 import re
 import traceback
 
-from bs_lib.AutoTransaction import AutoTransaction
-from bs_lib.Pod             import Pod
-from bs_lib                 import QueryBuilder
+from bs_lib.auto_transaction import AutoTransaction
+from bs_lib import Pod
+from bs_lib import query_builder
 
 from bs_loco.loco_template  import LocoTemplate
 from bs_loco.xloco          import xLoco
@@ -152,16 +151,16 @@ class Provider:
 
         with AutoTransaction(self._pod) as at:
             try:
-                dmsg.lock_one_deft(msg_id, self._pod.stdDBLock())
+                dmsg.lock_one_deft(msg_id, self._pod.std_db_lock())
 
                 if self.corrtype_id() != dmsg.rec.corrtype_id:
-                    raise Exception('Internal error, provider received wrong message type. [corrtype_id:%s, msg:%s]' % (
-                        self.corrtype_id(), str(dmsg.rec)))
+                    raise Exception(f'Internal error, provider received wrong message type. [corrtype_id:{self.corrtype_id()}'
+                                    f', {dmsg.rec}]')
 
 
                 if dmsg.rec.status != tMsg.Status_Couplet.key_pending and\
                    dmsg.rec.status != tMsg.Status_Couplet.key_retry:
-                    self._log.warning('  - skipping msg in unexepcted status [status:%s]' % (dmsg.rec.status))
+                    self._log.warning(f'  - skipping msg in unexepcted status [status:{dmsg.rec.status}]')
                     return True
 
                 if dmsg.rec.status == tMsg.Status_Couplet.key_retry:
@@ -180,8 +179,7 @@ class Provider:
                 ntrec = self._cache['notype'][dmsg.rec.notype_id]
 
                 if ntrec.status != tNoType.Status_Couplet.key_active:
-                    self._log.warning('  - skipping message, because the notification type is not active: [msg:%s]' % (
-                        str(dmsg.rec)))
+                    self._log.warning(f'  - skipping message, because the notification type is not active: [{dmsg.rec}]')
                     dmsg.rec.status = tMsg.Status_Couplet.key_cancelled
                     dmsg.rec.msglog = self._push_msg_log(dmsg.rec.msglog, 'Notification type is disabled')
                     dmsg.update()
@@ -194,29 +192,27 @@ class Provider:
                     dtnow = datetime.datetime.now()
 
                     if dreq.rec.time_to_send + datetime.timedelta(minutes=ntrec.max_life) < dtnow:
-                        self._log.warning('  - skipping message, max life reached: [max_life:%d, now:%s, req_time:%s, msg:%s]' % (  # noqa
-                            ntrec.max_life, str(dtnow), str(dreq.rec.time_to_send), str(dmsg.rec)))
+                        self._log.warning(f'  - skipping message, max life reached: [max_life:{ntrec.max_life}, now:{dtnow}'
+                                          f', req_time:{dreq.rec.time_to_send}, {dmsg.rec}]')
                         dmsg.rec.status = tMsg.Status_Couplet.key_cancelled
-                        dmsg.rec.msglog = self._push_msg_log(dmsg.rec.msglog, 'Max life reached [%d min]' % (ntrec.max_life))
+                        dmsg.rec.msglog = self._push_msg_log(dmsg.rec.msglog, f'Max life reached [{ntrec.max_life} min]')
                         dmsg.update()
                         at.commit()
                         return False
 
                 try:
                     if dmsg.rec.corrprov_id == self.id() and dmsg.rec.payload:
-                        payload = json.loads(dmsg.rec.payload)
+                        payload = dmsg.rec.payload
                     else:
                         payload          = self._build_payload(dreq.rec)
-                        dmsg.rec.payload = json.dumps(payload)
+                        dmsg.rec.payload = payload
 
                     resource_list = self._load_msgreq_resources(dreq.rec)
                 except Exception:
 
                     tb = traceback.format_exc()
 
-                    self._log.error('Exception building payload or loading resources [msg_id:%d, provider:%s]' % (
-                        msg_id, self.id()))
-
+                    self._log.error(f'Exception building payload or loading resources [msg_id:{msg_id}, provider:{self.id()}]')
                     self._log.error(tb)
 
                     dmsg.rec.status    = tMsg.Status_Couplet.key_template_error
@@ -226,12 +222,12 @@ class Provider:
                     at.commit()
                     return False
 
-                msg_addr = json.loads(dreq.rec.msg_addr)
+                msg_addr = dreq.rec.msg_addr
                 addr_list = self._addresses_allowed(msg_addr.get(self.corrtype_id()))
 
                 if not addr_list:
-                    self._log.warning('  - skipping message, because none of the addresses match\
- the allowed [msg:%s, addresses:%s]' % (str(dmsg.rec), str(msg_addr.get(self.corrtype_id()))))
+                    self._log.warning(f'  - skipping message, because none of the addresses match the allowed [msg:{dmsg.rec}'
+                                      f', addresses:{msg_addr.get(self.corrtype_id())}]')
                     dmsg.rec.status = tMsg.Status_Couplet.key_cancelled
                     dmsg.rec.msglog = self._push_msg_log(dmsg.rec.msglog, 'No addresses are allowed.')
                     dmsg.update()
@@ -262,11 +258,11 @@ class Provider:
                 at.commit()
 
             except Exception as x:
-                self._log.error('Exception caught sending [msg_id:%d, provider:%s]' % (msg_id, self.id()))
+                self._log.error(f'Exception caught sending [msg_id:{msg_id}, provider:{self.id()}]')
                 self._log.exception(x)
                 raise
 
-        self._log.debug('send - done [msgId:%d, status:%s]' % (dmsg.rec.id, tMsg.Status_Couplet.get_value(dmsg.rec.status)))
+        self._log.debug(f'send - done [msgId:{dmsg.rec.id}, status:{tMsg.Status_Couplet.get_value(dmsg.rec.status)}]')
 
         return dmsg.rec.status == tMsg.Status_Couplet.key_sent
 
@@ -326,7 +322,7 @@ class Provider:
                 ntempld = self._dao.dNoTempl(self._pod.dbcon)
                 ntempld.select_one_deft(msg.notype_id, msg.corrtype_id)
 
-                self._cache['templ'][ntd.rec.id] = self._validate_template(json.loads(ntempld.rec.templ))
+                self._cache['templ'][ntd.rec.id] = self._validate_template(ntempld.rec.templ)
                 self._cache['res'][ntd.rec.id]   = self._load_template_resources(ntempld.rec.res_list)
 
             if self._cache['keypair'] is None:
@@ -350,38 +346,32 @@ class Provider:
                         allow.append(re.compile(aqry.orec.regex))
                     except Exception as x:
                         self._log.exception(x)
-                        self._log.error('Failed to compile the allow regex: [%s]' % (str(aqry.orec)))
+                        self._log.error(f'Failed to compile the allow regex: {aqry.orec}')
                         raise
 
                 self._cache['allow'] = allow
 
         except Exception as x:
-            self._log.error('Exception caught initializing cache for message: [%s]' % (str(msg)))
+            self._log.error(f'Exception caught initializing cache for message: [{msg}]')
             self._log.exception(x)
             return False, str(x)
 
         return True, None
 
 
-    def _push_msg_log(self, msglog: str, err_msg: str) -> str:
+    def _push_msg_log(self, msglog: list, err_msg: str) -> list:
         """
         Pushes a message onto the message log.
         """
         if not msglog:
-            return json.dumps([err_msg])
+            return [ err_msg ]
 
-        try:
-            logs = json.loads(msglog)
+        msglog.insert(0, err_msg)
 
-            logs.insert(0, err_msg)
+        if len(msglog) > 10:
+            msglog.pop()
 
-            if len(logs) > 10:
-                logs.pop()
-
-            return json.dumps(logs)
-
-        except Exception as x:
-            return json.dumps([str(x)])
+        return msglog
 
 
     def _load_msgreq_resources(self, req: tMsgReq) -> list:
@@ -395,7 +385,7 @@ class Provider:
             return None
 
         res = []
-        crit = " and mr.corr_id_list ? '%s'" % self.corrtype_id()
+        crit = f" and mr.corr_id_list ? '{self.corrtype_id()}'"
 
         self._dao.dMsgReqResByMsgReq(self._pod.dbcon).exec_deft(req.id, crit).fetch_all(res)
 
@@ -412,24 +402,19 @@ class Provider:
         return templ
 
 
-    def _load_template_resources(self, res_list: str):
+    def _load_template_resources(self, res_list: list):
         """
         Loads the template resources for by name.
 
-        :param res_list: A json string of resource items.
+        :param res_list: A list of resource items.
         :return: The resource objects.
         """
         if not res_list:
             return None
 
-        rlist = json.loads(res_list)
-
-        if not rlist:
-            return None
-
         res = []
 
-        self._dao.dNoResSearch(self._pod.dbcon).exec_deft(QueryBuilder.dynList(rlist, 'nr', 'id')).fetch_all(res)
+        self._dao.dNoResSearch(self._pod.dbcon).exec_deft(query_builder.dyn_list(res_list, 'nr', 'id')).fetch_all(res)
 
         return res
 
@@ -483,7 +468,8 @@ class Provider:
             res.update(templ_kpair)
 
         if req.msg_dict:
-            kpair = json.loads(req.msg_dict)
+            kpair = req.msg_dict
+
             if not isinstance(kpair, dict):
                 raise xLoco('Invalid keypair object [msgreq: %s]' % (str(req)))
 
