@@ -60,7 +60,7 @@ class BaseLocoTrig:
                 'empty'     : False,
                 'nullable'  : False,
                 'maxlength' : 256,
-                'regex'     : '^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\\.[a-zA-Z0-9-.]+$',
+                'regex'     : "^['a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\\.[a-zA-Z0-9-.]+$",
             },
         },
     }
